@@ -66,7 +66,7 @@ class TemplateBackend:
 
         return response
 
-    def send(self, template_name, from_email, recipient_list, context, fail_silently=False):
+    def send(self, template_name, from_email, recipient_list, context, fail_silently=False, headers={}):
         subject = getattr(
                         settings,'TEMPLATED_EMAIL_DJANGO_SUBJECTS',{}
                     ).get(
@@ -84,6 +84,7 @@ class TemplateBackend:
                 parts['plain'],
                 from_email,
                 recipient_list,
+                headers = headers,
             )
             e.send(fail_silently)
 
@@ -93,6 +94,7 @@ class TemplateBackend:
                 parts['html'],
                 from_email,
                 recipient_list,
+                headers = headers,
             )
             e.content_subtype = 'html'
             e.send(fail_silently)
@@ -103,7 +105,10 @@ class TemplateBackend:
                 parts['plain'],
                 from_email,
                 recipient_list,
+                headers = headers,
             )
             e.attach_alternative(parts['html'],'text/html')
             e.send(fail_silently)
+        
+        return e.extra_headers.get('Message-Id',None)
 
